@@ -1,10 +1,12 @@
+# SPDX-FileCopyrightText: 2023 Konrad Weihmann
+# SPDX-License-Identifier: Zlib
 class MetricBase():
     def __init__(self, args, **kwargs):
         self._metrics = {"lang": []}
         self._internalstore = {}
 
     def parse_tokens(self, language, tokens):
-        if language not in self._metrics["lang"]:
+        if language not in self._metrics["lang"]:  # pragma: no cover
             self._metrics["lang"].append(language)
 
     def get_results(self):
@@ -21,4 +23,4 @@ class MetricBase():
         return res
 
     def get_results_global(self, value_stores):
-        return {}
\ No newline at end of file
+        return {}  # pragma: no cover
