@@ -1,3 +1,5 @@
+# SPDX-FileCopyrightText: 2023 Konrad Weihmann
+# SPDX-License-Identifier: Zlib
 class MetricBaseCalc():
 
     def __init__(self, args, **kwargs):
@@ -9,3 +11,6 @@ class MetricBaseCalc():
         This alters the originally passed metrics by calculated ones
         """
         return metrics
+
+    def get_internal_store(self):
+        return self._internalstore
