@@ -1,5 +1,7 @@
+# SPDX-FileCopyrightText: 2023 Konrad Weihmann
+# SPDX-License-Identifier: Zlib
 import csv
-import sys
+import logging
 
 from multimetric.cls.importer.base import Importer
 
@@ -17,4 +19,4 @@ class ImporterCSV(Importer):
                 for row in reader:
                     self._items.append(Importer.ImporterItem.from_csv(row))
         except Exception as e:
-            sys.stderr.write("Read error: {}\n".format(e))
+            logging.getLogger('stderr').error(f"Read error: {e}\n")
