@@ -1,5 +1,7 @@
+# SPDX-FileCopyrightText: 2023 Konrad Weihmann
+# SPDX-License-Identifier: Zlib
 import json
-import sys
+import logging
 
 from multimetric.cls.importer.base import Importer
 
@@ -15,9 +17,8 @@ class ImporterJSON(Importer):
             with open(self._input) as i:
                 reader = json.load(i)
                 for k, v in reader.items():
-                    _sev = None
-                    if "severity" in v:
-                        _sev = v["severity"]
-                    self._items.append(Importer.ImporterItem(_file=k, _cnt=v["content"], _sev=_sev))
+                    self._items.append(Importer.ImporterItem(_file=k,
+                                                             _sev=v["severity"],
+                                                             _cnt=v.get('content', None)))
         except Exception as e:
-            sys.stderr.write("Read error: {}\n".format(e))
+            logging.getLogger('stderr').error(f"Read error: {e}\n")
