@@ -1,3 +1,5 @@
+# SPDX-FileCopyrightText: 2023 Konrad Weihmann
+# SPDX-License-Identifier: Zlib
 from multimetric.cls.base import MetricBase
 
 
@@ -8,13 +10,13 @@ class MetricBaseComments(MetricBase):
         "Token.Comment.Multiline",
         "Token.Comment.Single",
         "Token.Comment.Special",
-        "Token.Literal.String.Doc"
+        "Token.Literal.String.Doc",
     ]
 
     _specific = {
         "Python": [
-            "Token.Comment.Preproc"
-        ]
+            "Token.Comment.Preproc",
+        ],
     }
 
     METRIC_COMMENT_RATIO = "comment_ratio"
@@ -28,18 +30,16 @@ class MetricBaseComments(MetricBase):
         super().parse_tokens(language, [])
         _n = MetricBaseComments._needles
         if language in MetricBaseComments._specific:
-            _n += MetricBaseComments._specific[language]
+            _n += MetricBaseComments._specific[language]  # pragma: no cover - bug in pytest-cov
         for x in tokens:
             self.__overall += len(str(x[1]))
             if str(x[0]) in _n:
-                self.__comments += len(str(x[1]))
+                self.__comments += len(str(x[1]))  # pragma: no cover - bug in pytest-cov
 
     def get_results(self):
-        if self.__overall == 0:
-            # sanity
-            self.__overall = 1
-        self._metrics[MetricBaseComments.METRIC_COMMENT_RATIO] = self.__comments * \
-            100.0 / float(self.__overall)
+        self.__overall = max(1, self.__overall)
+        self._metrics[MetricBaseComments.METRIC_COMMENT_RATIO] = (self.__comments *
+                                                                  100.0 / float(self.__overall))
         self._internalstore["comments"] = self.__comments
         self._internalstore["overall"] = self.__overall
         return self._metrics
@@ -51,5 +51,5 @@ class MetricBaseComments(MetricBase):
             __comments += x["comments"]
             __overall += x["overall"]
         return {
-            MetricBaseComments.METRIC_COMMENT_RATIO: __comments * 100.0 / float(__overall or 1.0)
+            MetricBaseComments.METRIC_COMMENT_RATIO: __comments * 100.0 / float(__overall or 1.0),
         }
